use strict;

# after ML was run, and the file final_params.txt was written, test the accuracy of these parameters on a given test set

# It uses ../../EnergyCG_other_predictors/Simfold/tools/predict_and_analyse_results_simfold
#   So make sure that's built properly

if ($#ARGV != 4)
{
    print "Usage: $0 <which_cluster> <test_set> <parameter_file> <model_options_file> <output_file>\n";
    print "<which_cluster> is arrow or icics\n";    
    print "<test_set> has to be a directory, and the prediction will be done on the sge icics cluster\n";
    exit;
}

my $which_cluster = $ARGV[0];
my $testset = $ARGV[1];
my $param_file = $ARGV[2];
my $model_options_file = $ARGV[3];
my $output_file = $ARGV[4];

if (!-e $param_file)
{
    print "File $param_file doesn't exist, ABORT!\n";
    exit;
}

# first figure out how many files there are in the testdir
if (! -d $testset)
{
    print "<test_dir> has to be a directory, ABORT!\n";
    exit;
}

my $num_split_files = `ls $testset/*.txt | wc -l`;
chomp ($num_split_files);
#print "There are $num_split_files files in $testset\n";

# then create the new datadir directory
my $new_testdir;
my $dir = ".";
# put new_testdir in the same directory as output_file
if ($output_file =~ /(\S+)\/[^\/]/)
{
    $dir = $1;
}
$new_testdir = "$dir/testdir";

system ("rm -rf $new_testdir");
system ("mkdir $new_testdir");

print "Test dir is $new_testdir\n";

#print "Submitting SGE array job\n";
# prepare the sge qsub command to run the prediction and analysis on the icics cluster
my $subcommand;
if ($model_options_file eq "none")
{
    $subcommand = "-cwd -m n -o /dev/null -e /dev/null -t 1000-". (1000+$num_split_files-1)."  sge_test_accuracy.sh $param_file $testset $new_testdir";
}
else
{
    $subcommand = "-cwd -m n -o /dev/null -e /dev/null -t 1000-". (1000+$num_split_files-1)."  sge_test_accuracy_extended.sh $param_file $testset $new_testdir $model_options_file";
}
#print "$command\n";
# run it via the wrapper which exits only when the jobs are done

my $command;
if ($which_cluster eq "arrow")
{
    $command = "nohup ssh samos \"cd ~/bio/Sandbox/Projects/EnergyML/IPOPT; perl start_sge_job.pl 'qsub -P kpm $subcommand '\"";
}
else    # icics/beta
{
    $command = "perl start_sge_job.pl 'qsub $subcommand'";
}

print "$command\n";
system("$command");

# once this finished, I have to collect and average the accuracy results, and add it to the results file
$command = "perl average_analysed_results.pl $new_testdir >> $output_file";
system ("$command");
system ("echo \"Params were final,   test set for above was: $testset\" >> $output_file");
system ("rm -rf $new_testdir");

